==> Tiny-Tiny-0.001.tar.gz: Tiny-Tiny-0.001/lib/Tiny/Tiny.pm <==
use strict;
use warnings;
package Tiny::Tiny;
{
  $Tiny::Tiny::VERSION = '0.001';
}
# git description: bdb95dc

BEGIN {
  $Tiny::Tiny::AUTHORITY = 'cpan:ETHER';
}
# ABSTRACT: minimal minimalism


1;

__END__

=pod

=for :stopwords Karen Etheridge

=head1 NAME

Tiny::Tiny - minimal minimalism

=head1 VERSION

version 0.001

=head1 SYNOPSIS

    use Tiny::Tiny;

=head1 DESCRIPTION

This module does the tiniest thing of all -- nothing!

Given all the recent releases of C<*::Tiny> modules, I felt like I needed to
get in on the action while there was still part of the namespace left.

=for html <center><img src="https://raw.github.com/karenetheridge/Tiny-Tiny/master/images/tiny-tim_lg.jpg" alt="Tiny Tim" width="216" height="267"/> <img src="https://raw.github.com/karenetheridge/Tiny-Tiny/master/images/Elton_John_Tiny_Dancer.jpg" alt="Tiny Dancer" width="260" height="320"/></center>

=head1 SUPPORT

Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Tiny-Tiny>
(or L<bug-Tiny-Tiny@rt.cpan.org|mailto:bug-Tiny-Tiny@rt.cpan.org>).
I am also usually active on irc, as 'ether' at C<irc.perl.org>.

=head1 SEE ALSO

There are many excellent (and legitimate) *::Tiny modules out there,
including:

=over 4

=item *

L<HTTP::Tiny>

=item *

L<Try::Tiny>

=item *

L<Role::Tiny>

=item *

L<Type::Tiny>

=back

=head1 AUTHOR

Karen Etheridge <ether@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Karen Etheridge.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Tiny-Tiny-0.002.tar.gz: Tiny-Tiny-0.002/lib/Tiny/Tiny.pm <==
use strict;
use warnings;
package Tiny::Tiny;
{
  $Tiny::Tiny::VERSION = '0.002';
}
# git description: v0.001-5-g073b3a8

BEGIN {
  $Tiny::Tiny::AUTHORITY = 'cpan:ETHER';
}
# ABSTRACT: minimal minimalism


1;

__END__

=pod

=encoding utf-8

=for :stopwords Karen Etheridge irc

=head1 NAME

Tiny::Tiny - minimal minimalism

=head1 VERSION

version 0.002

=head1 SYNOPSIS

    use Tiny::Tiny;

=head1 DESCRIPTION

This module does the tiniest thing of all -- nothing!

Given all the recent releases of C<*::Tiny> modules, I felt like I needed to
get in on the action while there was still part of the namespace left.

=for html <center><img src="https://raw.github.com/karenetheridge/Tiny-Tiny/master/images/tiny-tim_lg.jpg" alt="Tiny Tim" width="227" height="280"/>
<img src="https://raw.github.com/karenetheridge/Tiny-Tiny/master/images/Elton_John_Tiny_Dancer.jpg" alt="Tiny Dancer" width="276" height="280"/></center>

=head1 SUPPORT

Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Tiny-Tiny>
(or L<bug-Tiny-Tiny@rt.cpan.org|mailto:bug-Tiny-Tiny@rt.cpan.org>).
I am also usually active on irc, as 'ether' at C<irc.perl.org>.

=head1 SEE ALSO

There are many excellent (and legitimate) *::Tiny modules out there,
including:

=over 4

=item *

L<HTTP::Tiny>

=item *

L<Try::Tiny>

=item *

L<Role::Tiny>

=item *

L<Capture::Tiny>

=item *

L<Type::Tiny>

=back

=head1 AUTHOR

Karen Etheridge <ether@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Karen Etheridge.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
